Push word-wrapping position for text commands.

- `<0`: No wrapping.
- `=0`: Wrap to the end of the window or column.
- `>0`: Wrap at `wrap_pos_x` position in window local space.

See [ImGuiPopTextWrapPos].